Unicore CMS Django
==================

This is one to throw away.

Install on OSX
--------------

Install the packages in a virtualenv with pip.

.. code-block:: bash

    $ virtualenv ve
    $ source ve/bin/activate
    (ve)$ pip install -e .

Running Unicore CMS Django tests
-------------------------

.. code-block:: bash

    (ve)$ py.test cms
